@@ -8,6 +8,7 @@ from .menu import Menu, MenuEntry, MenuSeparator
 if TYPE_CHECKING:
     from ...ui.views.disassembly_view import DisassemblyView
 
+
 class DisasmInsnContextMenu(Menu):
     """
     Dissembly Instruction's Context Menu Items and callback funcion.
@@ -15,6 +16,7 @@ class DisasmInsnContextMenu(Menu):
     For adding items in plugins, use `Workspace.add_disasm_insn_ctx_menu_entry`
     and `Workspace.remove_disasm_insn_ctx_menu_entry`.
     """
+
     def __init__(self, disasm_view: 'DisassemblyView'):
         super().__init__("", parent=disasm_view)
 
@@ -33,10 +35,11 @@ class DisasmInsnContextMenu(Menu):
             ])
         self.entries.extend([
             MenuEntry('E&xecute symbolically...', self._popup_newstate_dialog),
-            MenuEntry('&Avoid in execution...', self._avoid_in_execution),
-            MenuEntry('&Find in execution...', self._find_in_execution),
+            MenuEntry('&Avoid in execution', self._avoid_in_execution),
+            MenuEntry('&Find in execution', self._find_in_execution),
             MenuEntry('Add &hook...', self._add_hook),
-            MenuEntry('View function &documentation...', self._view_docs)
+            MenuEntry('View function &documentation...', self._view_docs),
+            MenuEntry('Toggle &breakpoint', self._toggle_breakpoint)
         ])
 
     @property
@@ -60,6 +63,10 @@ class DisasmInsnContextMenu(Menu):
         self._disasm_view.find_addr_in_exec(self.insn_addr)
         self._disasm_view.refresh()
 
+    def _toggle_breakpoint(self):
+        self._disasm_view.workspace.instance.breakpoint_mgr.toggle_exec_breakpoint(self.insn_addr)
+        self._disasm_view.refresh()
+
     def _add_hook(self):
         self._disasm_view.popup_hook_dialog(async_=True)
 
@@ -94,4 +101,4 @@ class DisasmInsnContextMenu(Menu):
             if m.caption == text:
                 self.entries.remove(m)
                 if remove_preceding_separator:
-                    self.entries.pop(idx-1)
+                    self.entries.pop(idx - 1)
