@@ -1,5 +1,4 @@
-
 from .file_toolbar import FileToolbar
 from .function_table_toolbar import FunctionTableToolbar
 from .nav_toolbar import NavToolbar
-from .simgr_toolbar import SimgrToolbar
+from .debug_toolbar import DebugToolbar
