@@ -38,7 +38,8 @@ class CodeView(BaseView):
         self._function: Union[ObjectContainer, Function] = ObjectContainer(None, 'The function to decompile')
         self.current_node = ObjectContainer(None, 'Current selected C-code node')
         self.addr: Union[ObjectContainer, int] = ObjectContainer(0, "Current cursor address")
-        self.codegen: Union[ObjectContainer, CStructuredCodeGenerator] = ObjectContainer(None, "The currently-displayed codegen object")
+        self.codegen: Union[ObjectContainer, CStructuredCodeGenerator] = \
+            ObjectContainer(None, "The currently-displayed codegen object")
 
         self._last_function: Optional[Function] = None
         self._textedit: Optional[QCCodeEdit] = None
@@ -100,13 +101,14 @@ class CodeView(BaseView):
         self.vars_must_struct = set()
 
     def decompile(self, clear_prototype: bool=True, focus=False, focus_addr=None, flavor='pseudocode',
-                  reset_cache: bool=False):
+                  reset_cache: bool=False, regen_clinic: bool=True):
         if self._function.am_none:
             return
 
         if clear_prototype:
             # clear the existing function prototype
             self._function.prototype = None
+            self._function.ran_cca = False
 
         if reset_cache:
             self.workspace.instance.kb.structured_code.discard((self._function.addr, flavor))
@@ -137,6 +139,8 @@ class CodeView(BaseView):
             peephole_optimizations=self._options.selected_peephole_opts,
             vars_must_struct=self.vars_must_struct,
             on_finish=decomp_ready,
+            blocking=True,
+            regen_clinic=regen_clinic,
         )
 
         self.workspace.instance.add_job(job)
@@ -188,7 +192,8 @@ class CodeView(BaseView):
         self.addr.am_obj = self._textedit.get_src_to_inst()
         self.addr.am_event(already_moved=True)
 
-    def _on_codegen_changes(self, already_regenerated=False, event: Optional[str]=None, **kwargs):  # pylint: disable=unused-argument
+    # pylint: disable=unused-argument
+    def _on_codegen_changes(self, already_regenerated=False, event: Optional[str]=None, **kwargs):
         """
         The callback function that triggers an update of the codegen.
 
@@ -204,7 +209,22 @@ class CodeView(BaseView):
         if self.codegen.am_none:
             return
 
+        old_lineno: Optional[int] = None
+        old_node: Optional = None
+        old_font = None
+        if self._last_function is self._function.am_obj and self._doc is not None:
+            # we are re-rendering the current function (e.g., triggered by a node renaming). the cursor should stay at
+            # the same node
+            old_cursor: QTextCursor = self._textedit.textCursor()
+            old_pos = old_cursor.position()
+            old_lineno = old_cursor.blockNumber()
+            old_font = self._textedit.font()
+            # TODO: If multiple instances of the node is referenced at the same line, we will always select the first
+            #  node. We need to fix this by counting which node is selected.
+            old_node = self._doc.get_node_at_position(old_pos)
+
         self._view_selector.setCurrentText(self.codegen.flavor)
+
         if already_regenerated:
             # do not regenerate text
             pass
@@ -218,7 +238,7 @@ class CodeView(BaseView):
                 dec_cache = self.workspace.instance.kb.structured_code[(self._function.addr, 'pseudocode')]
                 new_codegen = dec.reflow_variable_types(
                     dec_cache.type_constraints,
-                    dec_cache.var_to_typevar,
+                    dec_cache.var_to_typevar or {},
                     dec_cache.codegen,
                 )
                 # update the cache
@@ -230,23 +250,27 @@ class CodeView(BaseView):
             # regenerate text in the end
             self.codegen.regenerate_text()
 
-        old_pos: Optional[int] = None
-        old_font = None
-        if self._last_function is self._function.am_obj:
-            # we are re-rendering the current function (e.g., triggered by a node renaming). save the old cursor and
-            # reuse it later.
-            old_cursor: QTextCursor = self._textedit.textCursor()
-            old_pos = old_cursor.position()
-            old_font = self._textedit.font()
-
         self._options.dirty = False
-        self._doc = QCodeDocument(self.codegen)
-        self._textedit.setDocument(self._doc)
+        if self._doc is None:
+            self._doc = QCodeDocument(self.codegen)
+            self._textedit.setDocument(self._doc)
+        else:
+            # only update the text. do not set a new document. this avoids scrolling the textedit up and down
+            self._doc._codegen = self.codegen
+            self._doc.setPlainText(self.codegen.text)
 
-        if old_pos is not None:
-            new_cursor: QTextCursor = self._textedit.textCursor()
-            new_cursor.setPosition(old_pos)
+        if old_lineno is not None:
+            the_block = self._doc.findBlockByNumber(old_lineno)
+            new_cursor: QTextCursor = QTextCursor(the_block)
             self._textedit.setFont(old_font)
+            if old_node is not None:
+                # find the first node starting from the current position
+                for pos in self.codegen.map_pos_to_node._posmap.irange(
+                        minimum=new_cursor.position(),
+                        maximum=new_cursor.position() + the_block.length()):
+                    elem = self.codegen.map_pos_to_node._posmap[pos]
+                    if elem.obj is old_node:
+                        new_cursor.setPosition(pos)
             self._textedit.setTextCursor(new_cursor)
 
         if self.codegen.flavor == 'pseudocode':
@@ -365,11 +389,13 @@ class CodeView(BaseView):
         for _ in range(self._view_selector.count()):
             self._view_selector.removeItem(0)
         self._view_selector.addItems(available)
+        self._view_selector.setVisible(len(available) >= 2)
 
     def _on_view_selector_changed(self, index):
-        key = (self._function.addr, self._view_selector.itemText(index))
-        self.codegen.am_obj = self.workspace.instance.kb.structured_code[key].codegen
-        self.codegen.am_event()
+        if not self._function.am_none:
+            key = (self._function.addr, self._view_selector.itemText(index))
+            self.codegen.am_obj = self.workspace.instance.kb.structured_code[key].codegen
+            self.codegen.am_event()
 
     #
     # Private methods
@@ -389,7 +415,7 @@ class CodeView(BaseView):
         textedit_dock.setWidget(self._textedit)
 
         # decompilation
-        self._options = QDecompilationOptions(self, self.workspace.instance, options=None)
+        self._options = QDecompilationOptions(self, self.workspace.instance)
         options_dock = QDockWidget('Decompilation Options', self._options)
         window.addDockWidget(Qt.RightDockWidgetArea, options_dock)
         options_dock.setWidget(self._options)
