@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, TYPE_CHECKING
 
 from PySide2.QtCore import Qt
 from PySide2.QtWidgets import QWidget, QVBoxLayout, QLineEdit, QTreeWidget, QTreeWidgetItem, QPushButton
@@ -7,27 +7,37 @@ from angr.analyses.decompiler.decompilation_options import options as dec_option
 from angr.analyses.decompiler.optimization_passes import get_optimization_passes, get_default_optimization_passes
 from angr.analyses.decompiler.peephole_optimizations import EXPR_OPTS, STMT_OPTS
 
+if TYPE_CHECKING:
+    from ..views.code_view import CodeView
+
 
 class OptionType:
+    """
+    An enum to determine what the .option field of a QDecompilationOption contains
+    """
     OPTION = 1
     OPTIMIZATION_PASS = 2
     PEEPHOLE_OPTIMIZATION = 3
 
 
 class QDecompilationOption(QTreeWidgetItem):
+    """
+    The UI entry for a single decompliation option. Get status with item.checkState(0).
+    """
     def __init__(self, parent, option, type_: int, enabled=True):
         super().__init__(parent)
         self.option = option
         self.type = type_
 
         if self.type == OptionType.OPTIMIZATION_PASS:
-            self.setText(0, option.__name__)
+            self.setText(0, option.NAME)
+            self.setToolTip(0, option.DESCRIPTION)
         elif self.type == OptionType.OPTION:
-            self.setText(0, option.name)
-            self.setToolTip(0, option.description)
+            self.setText(0, option.NAME)
+            self.setToolTip(0, option.DESCRIPTION)
         elif self.type == OptionType.PEEPHOLE_OPTIMIZATION:
-            self.setText(0, option.name)
-            self.setToolTip(0, option.description)
+            self.setText(0, option.NAME)
+            self.setToolTip(0, option.DESCRIPTION)
         else:
             raise NotImplementedError("Unsupported option type %s." % self.type_)
 
@@ -39,16 +49,23 @@ class QDecompilationOption(QTreeWidgetItem):
 
 
 class QDecompilationOptions(QWidget):
-    def __init__(self, code_view, instance, options=None, passes=None, peephole_opts=None):
+    """
+    The widget for selecting values for decompilation options. Will synchronize its status back to its parent (passed
+    in parameter) code view with the Apply button is pressed.
+
+    Since some options have default values depending on the current arch and os, it is important to call
+    reload(force=True) to reset values to their defaults whenever the current project changes.
+    """
+    def __init__(self, code_view, instance):
         super().__init__()
 
         self.dirty = True
 
-        self._code_view = code_view
+        self._code_view = code_view  # type: CodeView
         self._instance = instance
-        self._options = options
-        self._opti_passes = passes
-        self._peephole_opts = peephole_opts
+        self._options = None
+        self._opti_passes = None
+        self._peephole_opts = None
 
         # widgets
         self._search_box = None  # type:QLineEdit
@@ -61,7 +78,7 @@ class QDecompilationOptions(QWidget):
 
         self._init_widgets()
 
-        self.reload()
+        self.reload(True)
 
     def reload(self, force=False):
         if force or self._options is None:
@@ -76,7 +93,8 @@ class QDecompilationOptions(QWidget):
         if force or self._peephole_opts is None:
             self._peephole_opts = self.get_all_peephole_opts()
 
-        self._reload_options()
+        self._reload_options(force)
+        self._set_visibility(self._search_box.text())
 
     def _on_item_changed(self, item, _column):
         if getattr(item.option, 'clears_cache', True):
@@ -88,8 +106,9 @@ class QDecompilationOptions(QWidget):
             # clear the cached version
             self._code_view.decompile(reset_cache=True)
         else:
-            self._code_view.codegen.reapply_options(self.option_and_values)
-            self._code_view.codegen.am_event()
+            if not self._code_view.codegen.am_none:
+                self._code_view.codegen.reapply_options(self.option_and_values)
+                self._code_view.codegen.am_event()
 
     @property
     def selected_passes(self):
@@ -109,33 +128,22 @@ class QDecompilationOptions(QWidget):
 
     @property
     def option_and_values(self):
-        ov = [ ]
-        for item in self._qoptions:
-            if item.checkState(0):
-                ov.append((item.option, True))
-            else:
-                ov.append((item.option, False))
-        return ov
-
-    @property
-    def options(self):
-        return self._options
-
-    @options.setter
-    def options(self, v):
-        self._options = v
-        self._reload_options()
+        return [(item.option, bool(item.checkState(0))) for item in self._qoptions]
 
     def get_default_options(self):  # pylint: disable=no-self-use
         return dec_options
 
     def get_default_passes(self):
         if self._instance is None or self._instance.project.am_none:
-            return set()
-        return get_default_optimization_passes(self._instance.project.arch, self._instance.project.simos.name)
+            return []
+        return get_default_optimization_passes(self._instance.project.arch, self._instance.project.simos.name) + \
+            [x for x, de, in self._code_view.workspace.plugins.optimization_passes() if de]
 
     def get_all_passes(self):
-        return get_optimization_passes(self._instance.project.arch, self._instance.project.simos.name)
+        if self._instance is None or self._instance.project.am_none:
+            return []
+        return get_optimization_passes(self._instance.project.arch, self._instance.project.simos.name) + \
+            [x for x, _, in self._code_view.workspace.plugins.optimization_passes()]
 
     def get_default_peephole_opts(self):  # pylint: disable=no-self-use
         return STMT_OPTS + EXPR_OPTS
@@ -165,7 +173,10 @@ class QDecompilationOptions(QWidget):
 
         self.setLayout(layout)
 
-    def _reload_options(self, filter_by: Optional[str]=None):
+    def _reload_options(self, reset_values=False):
+        vals_options = dict(self.option_and_values)
+        vals_peephole = self.selected_peephole_opts
+        vals_passes = self.selected_passes
 
         self._treewidget.clear()
         self._qoptions.clear()
@@ -175,17 +186,15 @@ class QDecompilationOptions(QWidget):
         categories = { }
 
         # populate the tree widget with new options
-        for option in sorted(self._options, key=lambda x: x.name):
-            if filter_by:
-                if not (filter_by in option.name or filter_by in option.category):
-                    continue
+        for option in sorted(self._options, key=lambda x: x.NAME):
             if option.category in categories:
                 category = categories[option.category]
             else:
                 category = QTreeWidgetItem(self._treewidget, [option.category])
                 categories[option.category] = category
 
-            w = QDecompilationOption(category, option, OptionType.OPTION, enabled=option.default_value)
+            enabled = option.default_value if reset_values else vals_options.get(option, option.default_value)
+            w = QDecompilationOption(category, option, OptionType.OPTION, enabled=enabled)
             self._qoptions.append(w)
 
         passes_category = QTreeWidgetItem(self._treewidget, ["Optimization Passes"])
@@ -193,11 +202,8 @@ class QDecompilationOptions(QWidget):
 
         default_passes = set(self.get_default_passes())
         for pass_ in self._opti_passes:
-            if filter_by:
-                if not filter_by in pass_.__name__:
-                    continue
-            w = QDecompilationOption(passes_category, pass_, OptionType.OPTIMIZATION_PASS,
-                                     enabled=pass_ in default_passes)
+            enabled = pass_ in default_passes if reset_values else pass_ in vals_passes
+            w = QDecompilationOption(passes_category, pass_, OptionType.OPTIMIZATION_PASS, enabled=enabled)
             self._qoptipasses.append(w)
 
         po_category = QTreeWidgetItem(self._treewidget, ["Peephole Optimizations"])
@@ -205,15 +211,28 @@ class QDecompilationOptions(QWidget):
 
         default_peephole_opts = self.get_default_peephole_opts()
         for opt_ in self._peephole_opts:
-            if filter_by:
-                if not (filter_by in opt_.name or filter_by in opt_.description):
-                    continue
-            w = QDecompilationOption(po_category, opt_, OptionType.PEEPHOLE_OPTIMIZATION,
-                                     enabled=opt_ in default_peephole_opts)
+            enabled = opt_ in default_peephole_opts if reset_values else opt_ in vals_peephole
+            w = QDecompilationOption(po_category, opt_, OptionType.PEEPHOLE_OPTIMIZATION, enabled=enabled)
             self._qpeephole_opts.append(w)
 
         # expand all
         self._treewidget.expandAll()
 
+    def _set_visibility(self, filter_by: Optional[str]=None):
+        for w in self._qoptions:
+            w.setHidden(
+                bool(filter_by) and not (filter_by in w.option.NAME.lower() or filter_by in w.option.category.lower())
+            )
+        for w in self._qoptipasses:
+            w.setHidden(
+                bool(filter_by) and not (filter_by in w.option.__name__.lower() or filter_by in w.option.NAME.lower())
+            )
+        for w in self._qpeephole_opts:
+            w.setHidden(
+                bool(filter_by) and not (
+                        filter_by in w.option.NAME.lower() or filter_by in w.option.DESCRIPTION.lower()
+                )
+            )
+
     def _on_search_box_text_changed(self, text: str):
-        self._reload_options(filter_by=text)
+        self._set_visibility(filter_by=text)
