@@ -71,7 +71,7 @@ def get_block_objects(disasm, nodes, func_addr):
     if block_addr == func_addr:
         # function header
         func = disasm.kb.functions.get_by_addr(func_addr)
-        if func is not None and func.calling_convention is not None:
+        if func is not None and func.calling_convention is not None and func.prototype is not None:
             args = func.calling_convention.arg_locs(func.prototype)
             func_header = FunctionHeader(func.demangled_name, func.prototype, args)
             lst.append(func_header)
